@@ -17,12 +17,14 @@ class SessionHandler:
 
         self._dict = {}
 
-    def init_session(self, response) -> None:
+    def init_session(self, response):
         key = secrets.token_urlsafe(50)
         response.set_cookie("secret_key", key+self.secret_key,
                             httponly=True, max_age=self.lifetime)
 
         self._dict[key] = {}
+        
+        return response
 
     def __call__(self, request):
         if request.cookies.get("secret_key") in self._dict:
